==> i18next-2.0.4.jar: META-INF/resources/webjars/i18next/2.0.4/README.md <==
# i18next

i18next is a very popular internationalization framework for browser or any other javascript environment (eg. node.js).

The current v2 release is a big milestone in keeping continuity for your translation projects by keeping a stable, modern API.

i18next provides:

- Flexible connection to [backend](http://i18next.com/docs/ecosystem/#backends) (loading translations via xhr, ...)
- Optional [caching](http://i18next.com/docs/ecosystem/#caches), user [language detection](http://i18next.com/docs/ecosystem/#languagedetector), ...
- Proper [pluralizations](http://i18next.com/translate/pluralSimple/)
- Translation [context](http://i18next.com/translate/context/)
- [Nesting](http://i18next.com/translate/nesting/), [Variable replacement](http://i18next.com/translate/interpolation/)
- Flexibility: prefer [keybased](http://i18next.com/translate/) or [gettext](http://i18next.com/translate/keyBasedFallback/) style? No problem...
- Extensibility: eg. [sprintf](http://i18next.com/docs/ecosystem/#postprocessors)
- ...


For more information visit the website:

- [Getting started](http://i18next.com/docs/)
- [Translation Functionality](http://i18next.com/translate/)
- [API](http://i18next.com/docs/api/)
- [Migration Guide from v1.11.x](http://i18next.com/docs/migration/)



Our focus is providing the core to building a booming ecosystem. Independent of the building blocks you choose, be it react, angular or even good old jquery proper translation capabilities are just [one step away](http://i18next.com/docs/ecosystem/#frameworks).

==> i18next-2.0.22.jar: META-INF/resources/webjars/i18next/2.0.22/README.md <==
# i18next

[![Travis](https://img.shields.io/travis/i18next/i18next/master.svg?style=flat-square)](https://travis-ci.org/i18next/i18next)
[![Coveralls](https://img.shields.io/coveralls/i18next/i18next/master.svg?style=flat-square)](https://coveralls.io/github/i18next/i18next)
[![npm version](https://img.shields.io/npm/v/i18next.svg?style=flat-square)](https://www.npmjs.com/package/i18next)
[![Bower](https://img.shields.io/bower/v/i18next.svg)]()
[![David](https://img.shields.io/david/i18next/i18next.svg?style=flat-square)](https://david-dm.org/i18next/i18next)

i18next is a very popular internationalization framework for browser or any other javascript environment (eg. node.js).

The current v2 release is a big milestone in keeping continuity for your translation projects by keeping a stable, modern API.

i18next provides:

- Flexible connection to [backend](http://i18next.com/docs/ecosystem/#backends) (loading translations via xhr, ...)
- Optional [caching](http://i18next.com/docs/ecosystem/#caches), user [language detection](http://i18next.com/docs/ecosystem/#languagedetector), ...
- Proper [pluralizations](http://i18next.com/translate/pluralSimple/)
- Translation [context](http://i18next.com/translate/context/)
- [Nesting](http://i18next.com/translate/nesting/), [Variable replacement](http://i18next.com/translate/interpolation/)
- Flexibility: prefer [keybased](http://i18next.com/translate/) or [gettext](http://i18next.com/translate/keyBasedFallback/) style? No problem...
- Extensibility: eg. [sprintf](http://i18next.com/docs/ecosystem/#postprocessors)
- ...


For more information visit the website:

- [Getting started](http://i18next.com/docs/)
- [Translation Functionality](http://i18next.com/translate/)
- [API](http://i18next.com/docs/api/)
- [Migration Guide from v1.11.x](http://i18next.com/docs/migration/)



Our focus is providing the core to building a booming ecosystem. Independent of the building blocks you choose, be it react, angular or even good old jquery proper translation capabilities are just [one step away](http://i18next.com/docs/ecosystem/#frameworks).
